@@ -14,13 +14,15 @@ default_timeout_seconds = 300
 
 VALID_MATCH_MODES = ('exact', 'substring')
 
+VALID_MATCH_ORDERS = ('sequential', 'none')
+
 
 class Step:
     def __init__(self, parameters, shell):
         self.observed_output = {
-                "stdout": "",
-                "stderr": ""
-                }
+            "stdout": "",
+            "stderr": ""
+        }
         self.return_values = ""
         self.commands = []
         self.background = False if "background" not in parameters else parameters["background"]
@@ -37,6 +39,7 @@ class Step:
         self.env = dict(os.environ, **parameters['env']) if "env" in parameters else os.environ
         self.pause_message = None if "manual_pause_message" not in parameters else parameters["manual_pause_message"]
         self.match_mode = 'exact' if "output_match_mode" not in parameters else parameters["output_match_mode"]
+        self.match_order = "sequential" if "match_order" not in parameters else parameters["match_order"]
         self.tags = [] if "tags" not in parameters else parameters["tags"]
         self.shell = shell
 
@@ -44,6 +47,10 @@ class Step:
             from mechanical_markdown.parsers import MarkdownAnnotationError
             raise MarkdownAnnotationError(f'output_match_mode must be one of: {VALID_MATCH_MODES}')
 
+        if self.match_order not in VALID_MATCH_ORDERS:
+            from mechanical_markdown.parsers import MarkdownAnnotationError
+            raise MarkdownAnnotationError(f'match_order must be one of: {VALID_MATCH_ORDERS}')
+
     def add_command_block(self, block):
         self.commands.append(Command(block.strip(), self.working_dir, self.env, self.shell, self.timeout + self.sleep))
 
@@ -92,6 +99,13 @@ class Step:
                     success = False
         return success
 
+    @classmethod
+    def find_substring_in_list(cls, expected, lines):
+        for idx, line in enumerate(lines):
+            if expected in line:
+                return idx
+        return -1
+
     def validate_and_report(self):
         success = True
         report = ""
@@ -110,28 +124,55 @@ class Step:
                 report += f"\tduration_seconds: {c.duration_seconds:.{3}}\n"
 
         for out in 'stdout', 'stderr':
-            report += "\tExpected {} (output_match_mode: {}):\n".format(out, self.match_mode)
+            report += "\tExpected {} (output_match_mode: {}, match_order: {}):\n".format(
+                out, self.match_mode, self.match_order)
             for expected in self.expected_lines[out]:
                 report += '\t\t' + expected + '\n'
             report += "\tActual {}:\n".format(out)
 
+            not_found = {"stdout": [], "stderr": []}  # lines that were expected but not found
+            output_found_markers = []  # index of lines that were found in the output
+
+            # Gather output from all commands
+            output_lines = []
             for c in self.commands:
                 if c.process is not None:
-                    for line in c.output[out].split("\n"):
-                        if len(self.expected_lines[out]):
-                            if self.expected_lines[out][0] == line or (
-                               self.match_mode == 'substring' and self.expected_lines[out][0] in line):
-                                report += "\t\t{}\n".format(colored(line, 'green'))
-                                self.expected_lines[out] = self.expected_lines[out][1:]
-                            else:
-                                report += "\t\t{}\n".format(line)
-                        else:
-                            report += "\t\t{}\n".format(line)
+                    output_lines += c.output[out].split("\n")
 
-            if len(self.expected_lines[out]):
+            # Find expected lines in the output
+            output_lines_copy = output_lines[:]
+            for expected in self.expected_lines[out]:
+                if self.match_mode == 'exact':
+                    if expected in output_lines_copy:
+                        idx = output_lines_copy.index(expected)
+                        # remove the line so it can't be matched again, but keep the index
+                        output_lines_copy[idx] = ""
+                        output_found_markers.append(idx)
+                    else:
+                        not_found[out].append(expected)
+                elif self.match_mode == 'substring':
+                    idx = Step.find_substring_in_list(expected, output_lines_copy)
+                    if idx >= 0:
+                        # remove the line so it can't be matched again, but keep the index
+                        output_lines_copy[idx] = ""
+                        output_found_markers.append(idx)
+                    else:
+                        not_found[out].append(expected)
+
+            for idx, line in enumerate(output_lines):
+                if idx in output_found_markers:
+                    report += "\t\t{}\n".format(colored(line, 'green'))
+                else:
+                    report += "\t\t{}\n".format(line)
+
+            if self.match_order == 'sequential' and sorted(output_found_markers) != output_found_markers:
+                report += colored("\tERROR expected lines were not found in the correct order", 'red') + "\n"
+                success = False
+
+            if len(not_found[out]):
                 success = False
                 report += colored("\tERROR expected lines not found:", 'red') + "\n"
-                for line in self.expected_lines[out]:
+                for line in not_found[out]:
                     report += "\t\t" + colored(line, 'red') + "\n"
 
         return success, report
